@@ -452,7 +452,7 @@ def crms_pull(arg_model_url, arg_version, arg_target='', verbose=False):
     
     # repo = Repo.clone_from("git@github.com:jangcs/KKK.git", os.getcwd() )
     # modified_model_url = arg_model_url.replace('git@github.com:','https://github.com/',1)
-    modified_model_url = arg_model_url.replace('https://github.com/','git@github.com:',1)
+    modified_model_url = arg_model_url.replace('git@github.com:', 'https://github.com/',1)
 
     if arg_target != '' :
         target = arg_target
@@ -475,7 +475,7 @@ def crms_pull(arg_model_url, arg_version, arg_target='', verbose=False):
         with open(path_config) as f:
             configs = yaml.load(f, Loader=yaml.FullLoader)
             config_git_remote = configs['git']['remote'] 
-            modified_config_git_remote = config_git_remote.replace('https://github.com/','git@github.com:',1)
+            modified_config_git_remote = config_git_remote.replace('git@github.com:', 'https://github.com/',1)
 
             ### Check OK
             if modified_config_git_remote == modified_model_url :
@@ -531,8 +531,7 @@ def crms_pull(arg_model_url, arg_version, arg_target='', verbose=False):
             else :
                 print_verbose(verbose, "ERROR: " + target + " already exists, but it was not cloned from " + arg_model_url + ".")
                 raise Exception("CRMS ERROR: " + target + " already exists, but it was not cloned from " + arg_model_url + ".")
-                
-        raise Exception(target + " already exists.")
+
     # New direcotry
     else : 
         if verbose :
@@ -579,6 +578,59 @@ def crms_pull_cli(args):
     crms_pull(arg_model_url, arg_version, arg_target, verbose=True)
     print("CRMS PULL Completed !!!")
 
+
+
+def crms_clone(arg_model_url, arg_target='', verbose=False):
+    
+    # repo = Repo.clone_from("git@github.com:jangcs/KKK.git", os.getcwd() )
+    # modified_model_url = arg_model_url.replace('git@github.com:','https://github.com/',1)
+    modified_model_url = arg_model_url.replace('https://github.com/', 'git@github.com:',1)
+
+    if arg_target != '' :
+        target = arg_target
+    else :
+        # target = os.path.join( os.getcwd(), args.model_name)
+        # target = os.path.join( os.getcwd(), "model_crms")
+        target = os.path.join( os.getcwd(), os.path.basename(arg_model_url).split('.')[0] )   # git@github.com:jangcs/KKK.git -> KKK.git -> ['KKK', 'git']
+        
+    # Existing directory
+    if os.path.isdir(target) :
+        print_verbose(verbose, target + " already exists.")
+        raise Exception("CRMS Error : " + target + " already exists.")
+    # New direcotry
+    else : 
+        print_verbose(verbose, "crms_pull from "+ modified_model_url)
+        repo = Repo.clone_from(modified_model_url, target )
+
+        # if arg_version == 'latest' : 
+        ## only pull the latest version
+        os.chdir(target)
+        p = subprocess.run(["dvc", "pull"])
+        if p.returncode == 0 : # success of subprocess.run
+            print_verbose(verbose,"Pulled model files from DVC to " + target)
+        else: # fail of subprocess.run
+            print_verbose(verbose,"Failed to pull model files...")
+            raise Exception("CRMS failed to pull model files...")
+
+
+def crms_clone_cli(args):
+    print("CRMS CLONE....")
+    
+    if args.target != '' :
+        arg_target = args.target
+    else :
+        # target = os.path.join( os.getcwd(), args.model_name)
+        # target = os.path.join( os.getcwd(), "model_crms")
+        arg_target = os.path.join( os.getcwd(), os.path.basename(args.model_url).split('.')[0] )   # git@github.com:jangcs/KKK.git -> KKK.git -> ['KKK', 'git']
+
+    arg_model_url = args.model_url
+    # arg_version = 'latest'
+
+    crms_clone(arg_model_url, arg_target, verbose=True)
+    print("CRMS CLONE Completed !!!")
+
+
+
 def crms_desc(arg_model_name, verbose=False):
     
     if CRMS_META_REPOSITORY != '' :
@@ -685,6 +737,8 @@ def crms(args):
         crms_push_cli(args)
     elif args.cmd == 'pull' :
         crms_pull_cli(args)
+    elif args.cmd == 'clone' :
+        crms_clone_cli(args)
     elif args.cmd == 'list' :
         crms_list_cli(args)
     elif args.cmd == 'desc' :
@@ -704,6 +758,7 @@ def arg_parse() :
     parser_add  =   sub_parsers.add_parser('add',   help="CRMS ADDS MODEL_FILES: crms add <model_files>...")
     parser_push =   sub_parsers.add_parser('push',  help="CRMS PUSHES MODEL_FILES With VERSION_TAG : crms push <version>")
     parser_pull =   sub_parsers.add_parser('pull',  help="CRMS PULL MODEL With VERSION_TAG : crms pull <model_url> [--version=<latest>|<version_tag>] [--target=<target_dir>] ")
+    parser_clone =  sub_parsers.add_parser('clone',  help="CRMS CLONE MODEL With Latest Version : crms clone <model_url> [--target=<target_dir>] ")
     parser_list =   sub_parsers.add_parser('list',  help="CRMS LIST Models : crms list")
     parser_desc =   sub_parsers.add_parser('desc',  help="CRMS DESCRIBE MODEL Versions : crms desc <model_name> ")
 
@@ -724,6 +779,9 @@ def arg_parse() :
     parser_pull.add_argument("-v", "--version", type=str,  default="latest", action="store", help="--version=<latest>|<version_tag>")
     parser_pull.add_argument("-t", "--target", type=str,  default="", action="store", help="--target=<target_dir>")
 
+    parser_clone.add_argument("model_url",  action="store", help="model_url is required")
+    parser_clone.add_argument("-t", "--target", type=str,  default="", action="store", help="--target=<target_dir>")
+
     parser_desc.add_argument("model_name",  action="store", help="model_nameis required")
 
     args = arg_parser.parse_args()
